==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfStandardsConverter.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfStandardsConverter (SpireObject) :
    """
    The pdf standard conveter.
    """
    @dispatch
    def __init__(self, filePath:str):
        GetDllLibPdf().PdfStandardsConverter_CreatePdfStandardsConverterF.argtypes=[c_wchar_p]
        GetDllLibPdf().PdfStandardsConverter_CreatePdfStandardsConverterF.restype = c_void_p
        intPtr = GetDllLibPdf().PdfStandardsConverter_CreatePdfStandardsConverterF(filePath)
        super(PdfStandardsConverter, self).__init__(intPtr)

    @dispatch
    def __init__(self, stream:Stream):
        ptrStream:c_void_p = stream.Ptr
        GetDllLibPdf().PdfStandardsConverter_CreatePdfStandardsConverterS.argtypes=[c_void_p]
        GetDllLibPdf().PdfStandardsConverter_CreatePdfStandardsConverterS.restype = c_void_p
        intPtr = GetDllLibPdf().PdfStandardsConverter_CreatePdfStandardsConverterS(ptrStream)
        super(PdfStandardsConverter, self).__init__(intPtr)

    @dispatch

    def ToPdfA1B(self ,filePath:str):
        """
        Convert to pdf/a1b standard document.
		
        Args:
            filePath (str): The out file path.
        """
        
        GetDllLibPdf().PdfStandardsConverter_ToPdfA1B.argtypes=[c_void_p ,c_wchar_p]
        GetDllLibPdf().PdfStandardsConverter_ToPdfA1B(self.Ptr, filePath)

    @dispatch

    def ToPdfA1B(self ,stream:Stream):
        """
        Convert to pdf/a1b standard document.

        Args:
            stream (Stream): The out stream.	
        """
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfStandardsConverter_ToPdfA1BS.argtypes=[c_void_p ,c_void_p]
        GetDllLibPdf().PdfStandardsConverter_ToPdfA1BS(self.Ptr, intPtrstream)

    @dispatch

    def ToPdfA1A(self ,filePath:str):
        """
        Convert to pdf/a1a standard document.

        Args:
            filePath (str): The out file path.	
        """        
        GetDllLibPdf().PdfStandardsConverter_ToPdfA1A.argtypes=[c_void_p ,c_wchar_p]
        GetDllLibPdf().PdfStandardsConverter_ToPdfA1A(self.Ptr, filePath)

    @dispatch

    def ToPdfA1A(self ,stream:Stream):
        """
        Convert to pdf/a1b standard document.

        Args:
            stream (Stream): The out stream.	
        """		
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfStandardsConverter_ToPdfA1AS.argtypes=[c_void_p ,c_void_p]
        GetDllLibPdf().PdfStandardsConverter_ToPdfA1AS(self.Ptr, intPtrstream)

    @dispatch

    def ToPdfA2B(self ,filePath:str):
        """
        Convert to pdf/a2b standard document.

        Args:
            filePath (str): The out file path.	
        """        
        GetDllLibPdf().PdfStandardsConverter_ToPdfA2B.argtypes=[c_void_p ,c_wchar_p]
        GetDllLibPdf().PdfStandardsConverter_ToPdfA2B(self.Ptr, filePath)

    @dispatch

    def ToPdfA2B(self ,stream:Stream):
        """
        Convert to pdf/a2b standard document.

		Args:
		stream (Stream): The out stream.	
        """
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfStandardsConverter_ToPdfA2BS.argtypes=[c_void_p ,c_void_p]
        GetDllLibPdf().PdfStandardsConverter_ToPdfA2BS(self.Ptr, intPtrstream)

    @dispatch

    def ToPdfA2A(self ,filePath:str):
        """
        Convert to pdf/a2a standard document.

        Args:
            filePath (str): The out file path.	
        """          
        GetDllLibPdf().PdfStandardsConverter_ToPdfA2A.argtypes=[c_void_p ,c_wchar_p]
        GetDllLibPdf().PdfStandardsConverter_ToPdfA2A(self.Ptr, filePath)

    @dispatch

    def ToPdfA2A(self ,stream:Stream):
        """
        Convert to pdf/a2a standard document.

		Args:
		stream (Stream): The out stream.	
        """		
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfStandardsConverter_ToPdfA2AS.argtypes=[c_void_p ,c_void_p]
        GetDllLibPdf().PdfStandardsConverter_ToPdfA2AS(self.Ptr, intPtrstream)

    @dispatch

    def ToPdfA3B(self ,filePath:str):
        """
        Convert to pdf/a3b standard document.

        Args:
            filePath (str): The out file path.	
        """         
        GetDllLibPdf().PdfStandardsConverter_ToPdfA3B.argtypes=[c_void_p ,c_wchar_p]
        GetDllLibPdf().PdfStandardsConverter_ToPdfA3B(self.Ptr, filePath)

    @dispatch

    def ToPdfA3B(self ,stream:Stream):
        """
        Convert to pdf/a3b standard document.

		Args:
		stream (Stream): The out stream.	
        """			
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfStandardsConverter_ToPdfA3BS.argtypes=[c_void_p ,c_void_p]
        GetDllLibPdf().PdfStandardsConverter_ToPdfA3BS(self.Ptr, intPtrstream)

    @dispatch

    def ToPdfA3A(self ,filePath:str):
        """
        Convert to pdf/a2a standard document.

        Args:
            filePath (str): The out file path.	
        """        
        GetDllLibPdf().PdfStandardsConverter_ToPdfA3A.argtypes=[c_void_p ,c_wchar_p]
        GetDllLibPdf().PdfStandardsConverter_ToPdfA3A(self.Ptr, filePath)

    @dispatch

    def ToPdfA3A(self ,stream:Stream):
        """
        Convert to pdf/a3a standard document.

		Args:
		stream (Stream): The out stream.	
        """		
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfStandardsConverter_ToPdfA3AS.argtypes=[c_void_p ,c_void_p]
        GetDllLibPdf().PdfStandardsConverter_ToPdfA3AS(self.Ptr, intPtrstream)

    @dispatch

    def ToPdfX1A2001(self ,filePath:str):
        """
        Convert to pdf/x1a2001 standard document.

        Args:
            filePath (str): The out file path.	
        """        
        GetDllLibPdf().PdfStandardsConverter_ToPdfX1A2001.argtypes=[c_void_p ,c_wchar_p]
        GetDllLibPdf().PdfStandardsConverter_ToPdfX1A2001(self.Ptr, filePath)

    @dispatch

    def ToPdfX1A2001(self ,stream:Stream):
        """
        Convert to pdf/x1a2001 standard document.

		Args:
		stream (Stream): The out stream.	
        """		
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfStandardsConverter_ToPdfX1A2001S.argtypes=[c_void_p ,c_void_p]
        GetDllLibPdf().PdfStandardsConverter_ToPdfX1A2001S(self.Ptr, intPtrstream)

    def Dispose(self):
        """

        """
        GetDllLibPdf().PdfStandardsConverter_Dispose.argtypes=[c_void_p]
        GetDllLibPdf().PdfStandardsConverter_Dispose(self.Ptr)

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfStandardsConverter.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfStandardsConverter (SpireObject) :
    """
    The pdf standard conveter.
    """
    @dispatch
    def __init__(self, filePath:str):
        GetDllLibPdf().PdfStandardsConverter_CreatePdfStandardsConverterF.argtypes=[c_wchar_p]
        GetDllLibPdf().PdfStandardsConverter_CreatePdfStandardsConverterF.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStandardsConverter_CreatePdfStandardsConverterF,filePath)
        super(PdfStandardsConverter, self).__init__(intPtr)

    @dispatch
    def __init__(self, stream:Stream):
        ptrStream:c_void_p = stream.Ptr
        GetDllLibPdf().PdfStandardsConverter_CreatePdfStandardsConverterS.argtypes=[c_void_p]
        GetDllLibPdf().PdfStandardsConverter_CreatePdfStandardsConverterS.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStandardsConverter_CreatePdfStandardsConverterS,ptrStream)
        super(PdfStandardsConverter, self).__init__(intPtr)

    @dispatch

    def ToPdfA1B(self ,filePath:str):
        """
        Convert to pdf/a1b standard document.
		
        Args:
            filePath (str): The out file path.
        """
        
        GetDllLibPdf().PdfStandardsConverter_ToPdfA1B.argtypes=[c_void_p ,c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfStandardsConverter_ToPdfA1B,self.Ptr, filePath)

    @dispatch

    def ToPdfA1B(self ,stream:Stream):
        """
        Convert to pdf/a1b standard document.

        Args:
            stream (Stream): The out stream.	
        """
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfStandardsConverter_ToPdfA1BS.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibPdf().PdfStandardsConverter_ToPdfA1BS,self.Ptr, intPtrstream)

    @dispatch

    def ToPdfA1A(self ,filePath:str):
        """
        Convert to pdf/a1a standard document.

        Args:
            filePath (str): The out file path.	
        """        
        GetDllLibPdf().PdfStandardsConverter_ToPdfA1A.argtypes=[c_void_p ,c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfStandardsConverter_ToPdfA1A,self.Ptr, filePath)

    @dispatch

    def ToPdfA1A(self ,stream:Stream):
        """
        Convert to pdf/a1b standard document.

        Args:
            stream (Stream): The out stream.	
        """		
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfStandardsConverter_ToPdfA1AS.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibPdf().PdfStandardsConverter_ToPdfA1AS,self.Ptr, intPtrstream)

    @dispatch

    def ToPdfA2B(self ,filePath:str):
        """
        Convert to pdf/a2b standard document.

        Args:
            filePath (str): The out file path.	
        """        
        GetDllLibPdf().PdfStandardsConverter_ToPdfA2B.argtypes=[c_void_p ,c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfStandardsConverter_ToPdfA2B,self.Ptr, filePath)

    @dispatch

    def ToPdfA2B(self ,stream:Stream):
        """
        Convert to pdf/a2b standard document.

		Args:
		stream (Stream): The out stream.	
        """
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfStandardsConverter_ToPdfA2BS.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibPdf().PdfStandardsConverter_ToPdfA2BS,self.Ptr, intPtrstream)

    @dispatch

    def ToPdfA2A(self ,filePath:str):
        """
        Convert to pdf/a2a standard document.

        Args:
            filePath (str): The out file path.	
        """          
        GetDllLibPdf().PdfStandardsConverter_ToPdfA2A.argtypes=[c_void_p ,c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfStandardsConverter_ToPdfA2A,self.Ptr, filePath)

    @dispatch

    def ToPdfA2A(self ,stream:Stream):
        """
        Convert to pdf/a2a standard document.

		Args:
		stream (Stream): The out stream.	
        """		
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfStandardsConverter_ToPdfA2AS.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibPdf().PdfStandardsConverter_ToPdfA2AS,self.Ptr, intPtrstream)

    @dispatch

    def ToPdfA3B(self ,filePath:str):
        """
        Convert to pdf/a3b standard document.

        Args:
            filePath (str): The out file path.	
        """         
        GetDllLibPdf().PdfStandardsConverter_ToPdfA3B.argtypes=[c_void_p ,c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfStandardsConverter_ToPdfA3B,self.Ptr, filePath)

    @dispatch

    def ToPdfA3B(self ,stream:Stream):
        """
        Convert to pdf/a3b standard document.

		Args:
		stream (Stream): The out stream.	
        """			
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfStandardsConverter_ToPdfA3BS.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibPdf().PdfStandardsConverter_ToPdfA3BS,self.Ptr, intPtrstream)

    @dispatch

    def ToPdfA3A(self ,filePath:str):
        """
        Convert to pdf/a2a standard document.

        Args:
            filePath (str): The out file path.	
        """        
        GetDllLibPdf().PdfStandardsConverter_ToPdfA3A.argtypes=[c_void_p ,c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfStandardsConverter_ToPdfA3A,self.Ptr, filePath)

    @dispatch

    def ToPdfA3A(self ,stream:Stream):
        """
        Convert to pdf/a3a standard document.

		Args:
		stream (Stream): The out stream.	
        """		
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfStandardsConverter_ToPdfA3AS.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibPdf().PdfStandardsConverter_ToPdfA3AS,self.Ptr, intPtrstream)

    @dispatch

    def ToPdfX1A2001(self ,filePath:str):
        """
        Convert to pdf/x1a2001 standard document.

        Args:
            filePath (str): The out file path.	
        """        
        GetDllLibPdf().PdfStandardsConverter_ToPdfX1A2001.argtypes=[c_void_p ,c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfStandardsConverter_ToPdfX1A2001,self.Ptr, filePath)

    @dispatch

    def ToPdfX1A2001(self ,stream:Stream):
        """
        Convert to pdf/x1a2001 standard document.

		Args:
		stream (Stream): The out stream.	
        """		
        intPtrstream:c_void_p = stream.Ptr

        GetDllLibPdf().PdfStandardsConverter_ToPdfX1A2001S.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibPdf().PdfStandardsConverter_ToPdfX1A2001S,self.Ptr, intPtrstream)

    def Dispose(self):
        """

        """
        GetDllLibPdf().PdfStandardsConverter_Dispose.argtypes=[c_void_p]
        CallCFunction(GetDllLibPdf().PdfStandardsConverter_Dispose,self.Ptr)
